@@ -1,8 +1,13 @@
+import pathlib
+from pathlib import PosixPath
+from typing import Any, Dict, List, Optional, Tuple, Union
+
 import matplotlib.pylab as plt
 import numpy as np
+from numpy import complex128, float64, ndarray
 
-from modes import _mode_solver_lib as ms
 from modes._mode_solver import _ModeSolver
+from modes._mode_solver_lib import FDMode, _ModeSolverVectorial
 
 
 class ModeSolverFullyVectorial(_ModeSolver):
@@ -11,40 +16,38 @@ class ModeSolverFullyVectorial(_ModeSolver):
     setup and run a mode solving simulation.
 
     Args:
-        n_eigs (int): The number of eigen-values to solve for.
-        tol (float): The precision of the eigen-value/eigen-vector
+        n_eigs: number of eigen-values to solve for.
+        tol: The precision of the eigen-value/eigen-vector
             solver.  Default is 0.001.
         boundary (str): The boundary conditions to use.
             This is a string that identifies the type of boundary conditions applied.
-            The following options are available: 'A' - Hx is antisymmetric, Hy is symmetric,
-            'S' - Hx is symmetric and, Hy is antisymmetric, and '0' - Hx and Hy are zero
-            immediately outside of the boundary.
-            The string identifies all four boundary conditions, in the order:
-            North, south, east, west. For example, boundary='000A'. Default is '0000'.
+            'A' - Hx is antisymmetric, Hy is symmetric,
+            'S' - Hx is symmetric and, Hy is antisymmetric
+            '0' - Hx and Hy are zero immediately outside of the boundary.
+            The string identifies North, south, east, west boundary conditions
         initial_mode_guess (list): An initial mode guess for the modesolver.
         initial_n_eff_guess (list): An initial effective index guess for the modesolver.
     """
 
     def __init__(
         self,
-        n_eigs,
-        tol=0.001,
-        boundary="0000",
-        initial_mode_guess=None,
-        n_eff_guess=None,
-        name=None,
-        wg=None,
-    ):
+        n_eigs: int,
+        tol: float = 0.001,
+        boundary: str = "0000",
+        initial_mode_guess: Optional[float] = None,
+        n_eff_guess: Optional[float] = None,
+        wg: None = None,
+    ) -> None:
         self.n_effs_te = None
         self.n_effs_tm = None
-        self.name = name
+        self.name = "ModeSolverFullyVectorial"
         self.wg = wg
         _ModeSolver.__init__(
             self, n_eigs, tol, boundary, False, initial_mode_guess, n_eff_guess
         )
 
-    def solve(self):
-        """ Find the modes of a given structure.
+    def solve(self) -> Dict[str, Union[ndarray, List[FDMode]]]:
+        """Find the modes of a given structure.
 
         Returns:
             dict: The 'n_effs' key gives the effective indices
@@ -54,7 +57,7 @@ class ModeSolverFullyVectorial(_ModeSolver):
         """
         structure = self._structure = self.wg
         wavelength = self.wg._wl
-        self._ms = ms._ModeSolverVectorial(wavelength, structure, self._boundary)
+        self._ms = _ModeSolverVectorial(wavelength, structure, self._boundary)
         self._ms.solve(
             self._n_eigs,
             self._tol,
@@ -77,7 +80,7 @@ class ModeSolverFullyVectorial(_ModeSolver):
 
         return r
 
-    def _get_mode_types(self):
+    def _get_mode_types(self) -> List[Tuple[str, float64]]:
         mode_types = []
         labels = {0: "qTE", 1: "qTM", 2: "qTE/qTM"}
         for overlap in self.overlaps:
@@ -85,7 +88,11 @@ class ModeSolverFullyVectorial(_ModeSolver):
             mode_types.append((labels[idx], np.round(overlap[idx], 2)))
         return mode_types
 
-    def _sort_neffs(self, n_effs):
+    def _sort_neffs(
+        self, n_effs: ndarray
+    ) -> Union[
+        Tuple[List[complex128], List[complex128]], Tuple[List[complex128], List[Any]]
+    ]:
         mode_types = self._get_mode_types()
 
         n_effs_te = []
@@ -99,11 +106,13 @@ class ModeSolverFullyVectorial(_ModeSolver):
 
         return n_effs_te, n_effs_tm
 
-    def _get_overlaps(self, fields):
+    def _get_overlaps(
+        self, fields: List[FDMode]
+    ) -> Tuple[List[List[Union[float, float64]]], List[float64], List[float64]]:
         mode_areas = []
         fraction_te = []
         fraction_tm = []
-        for mode in self._ms.modes:
+        for mode in self.modes:
             e_fields = (mode.fields["Ex"], mode.fields["Ey"], mode.fields["Ez"])
             h_fields = (mode.fields["Hx"], mode.fields["Hy"], mode.fields["Hz"])
 
@@ -126,11 +135,18 @@ class ModeSolverFullyVectorial(_ModeSolver):
 
     def write_modes_to_file(
         self,
-        filename="mode.dat",
-        plot=True,
-        fields_to_write=("Ex", "Ey", "Ez", "Hx", "Hy", "Hz"),
-        logscale=False,
-    ):
+        filename: PosixPath = "mode.dat",
+        plot: bool = True,
+        fields_to_write: Tuple[str, ...] = (
+            "Ex",
+            "Ey",
+            "Ez",
+            "Hx",
+            "Hy",
+            "Hz",
+        ),
+        logscale: bool = False,
+    ) -> List[FDMode]:
         """
         Writes the mode fields to a file and optionally plots them.
 
@@ -153,6 +169,7 @@ class ModeSolverFullyVectorial(_ModeSolver):
         """
 
         # Mode info file.
+        filename = pathlib.Path(filename)
         filename_info = filename.parent / f"{filename.stem}_info.dat"
         with open(filename_info, "w") as fs:
             fs.write("# Mode idx, Mode type, % in major direction, n_eff\n")
@@ -169,7 +186,7 @@ class ModeSolverFullyVectorial(_ModeSolver):
                 fs.write(line + "\n")
 
         # Mode field plots.
-        for i, (mode, areas) in enumerate(zip(self._ms.modes, self.overlaps)):
+        for i, (mode, areas) in enumerate(zip(self.modes, self.overlaps)):
             filename_full = filename.parent / (filename.stem + f"_{i}.dat")
 
             for (field_name, field_profile), area in zip(mode.fields.items(), areas):
@@ -194,12 +211,20 @@ class ModeSolverFullyVectorial(_ModeSolver):
 
     def plot_modes(
         self,
-        filename,
-        fields_to_write=("Ex", "Ey", "Ez", "Hx", "Hy", "Hz"),
-        logscale=False,
-    ):
+        filename: PosixPath,
+        fields_to_write: Tuple[str, ...] = (
+            "Ex",
+            "Ey",
+            "Ez",
+            "Hx",
+            "Hy",
+            "Hz",
+        ),
+        logscale: bool = False,
+    ) -> None:
         """ works only for cached modes """
         # Mode field plots.
+        filename = pathlib.Path(filename)
         for i, mode in enumerate(self.modes):
             filename_full = filename.parent / (filename.stem + f"_{i}.dat")
 
@@ -218,3 +243,9 @@ class ModeSolverFullyVectorial(_ModeSolver):
                         wavelength=self.wg._wl,
                         logscale=logscale,
                     )
+
+
+if __name__ == "__main__":
+    from modes.waveguide import waveguide
+
+    ms = ModeSolverFullyVectorial(n_eigs=1, wg=waveguide())
