@@ -1,21 +1,19 @@
 import json
+from typing import Optional, Tuple
 
 import numpy as np
 import pytest
 
-from modes._mode_solver import get_modes_jsonpath
 from modes._mode_solver_full_vectorial import ModeSolverFullyVectorial
-from modes.autoname import autoname
-from modes.autoname import clean_value
-from modes.materials import nitride
-from modes.materials import si
-from modes.materials import sio2
-from modes.waveguide import waveguide
-from modes.waveguide import write_material_index
+from modes._structure import RidgeWaveguide
+from modes.autoname import autoname, clean_value
+from modes.get_modes_jsonpath import get_modes_jsonpath
+from modes.materials import nitride, sio2
+from modes.waveguide import waveguide, write_material_index
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_mode_solver_full_vectorial(overwrite):
+def test_mode_solver_full_vectorial(overwrite: bool) -> None:
     mode_solver = mode_solver_full(overwrite=overwrite, logscale=True, plot=True)
     # modes = mode_solver.solve()
     # neff0 = modes["n_effs"][0].real
@@ -26,12 +24,12 @@ def test_mode_solver_full_vectorial(overwrite):
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_mode_solver_full_vectorial_multi_clad(overwrite):
+def test_mode_solver_full_vectorial_multi_clad(overwrite: bool) -> None:
     mode_solver = mode_solver_full(
         overwrite=overwrite,
         logscale=True,
         plot=False,
-        clad_height=[50e-3, 50e-3, 0.5],
+        clad_thickness=[50e-3, 50e-3, 0.5],
         n_clads=[sio2, nitride, sio2],
     )
     # modes = mode_solver.solve()
@@ -43,7 +41,13 @@ def test_mode_solver_full_vectorial_multi_clad(overwrite):
 
 
 @autoname
-def _full(n_modes=2, wg=None, plot=True, plot_profile=False, **wg_kwargs):
+def _full(
+    n_modes: int = 2,
+    wg: Optional[RidgeWaveguide] = None,
+    plot: bool = True,
+    plot_profile: bool = False,
+    **wg_kwargs
+) -> ModeSolverFullyVectorial:
     """
     returns mode solver with mode_solver.wg
     writes waveguide material index
@@ -65,41 +69,48 @@ def _full(n_modes=2, wg=None, plot=True, plot_profile=False, **wg_kwargs):
 
 
 def mode_solver_full(
-    n_modes=2,
-    overwrite=False,
-    plot=False,
-    plot_profile=False,
-    logscale=False,
-    wg=None,
-    fields_to_write=("Ex", "Ey", "Ez", "Hx", "Hy", "Hz"),
+    n_modes: int = 2,
+    overwrite: bool = False,
+    plot: bool = False,
+    plot_profile: bool = False,
+    logscale: bool = False,
+    wg: Optional[RidgeWaveguide] = None,
+    fields_to_write: Tuple[str, ...] = (
+        "Ex",
+        "Ey",
+        "Ez",
+        "Hx",
+        "Hy",
+        "Hz",
+    ),
     **wg_kwargs
-):
+) -> ModeSolverFullyVectorial:
     """
     returns full vectorial mode solver with the computed modes
 
     Args:
         n_modes: 2
         overwrite: whether to run again even if it finds the modes in CONFIG.cache
-        x_step: 0.02
-        y_step: 0.02
-        wg_height: 0.22
-        wg_width: 0.5
-        slab_height: 0
-        sub_height: 0.5
-        sub_width: 2.0
-        clad_height: 0.5
-        n_sub: sio2
-        n_wg: si
-        n_clad: sio2
-        wavelength: 1.55
-        angle: 90.0
+        x_step: 0.02 grid step (um)
+        y_step: 0.02 grid step (um)
+        thickness: 0.22 (um)
+        width: 0.5 (um)
+        slab_thickness: 0 (um)
+        sub_width: 2.0 related to the total simulation width
+        sub_thickness: 0.5 bottom simulation margin
+        clad_thickness: [0.5]  List of claddings (top simulation margin)
+        n_sub: sio2 substrate index material
+        n_wg: si waveguide index material
+        n_clads: list of cladding materials [sio2]
+        wavelength: 1.55 wavelength (um)
+        angle: 90 sidewall angle (degrees)
 
     .. plot::
       :include-source:
 
       import modes as ms
 
-      s = ms.mode_solver_full(plot=True, n_modes=1, wg_width=0.5, wg_height=0.22)
+      s = ms.mode_solver_full(plot=True, n_modes=1, width=0.5, thickness=0.22)
       print(s.results.keys())
 
     """
@@ -173,7 +184,9 @@ def mode_solver_full(
         mode_solver.modes = r["modes"]
         mode_solver.n_effs = r["n_effs"]
         if plot:
-            mode_solver.plot_modes(filepath, fields_to_write=fields_to_write)
+            mode_solver.plot_modes(
+                filepath, fields_to_write=fields_to_write, logscale=logscale
+            )
 
     mode_solver.results = r
     return mode_solver
