@@ -3,16 +3,14 @@ import json
 import numpy as np
 import pytest
 
-from modes._mode_solver import get_modes_jsonpath
 from modes._mode_solver_semi_vectorial import ModeSolverSemiVectorial
-from modes.autoname import autoname
-from modes.autoname import clean_value
-from modes.waveguide import waveguide
-from modes.waveguide import write_material_index
+from modes.autoname import autoname, clean_value
+from modes.get_modes_jsonpath import get_modes_jsonpath
+from modes.waveguide import waveguide, write_material_index
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_mode_solver_semi_vectorial_te(overwrite):
+def test_mode_solver_semi_vectorial_te(overwrite: bool) -> None:
     mode_solver = mode_solver_semi(overwrite=overwrite)
     # modes = mode_solver.solve()
     # neff0 = modes["n_effs"][0].real
@@ -23,7 +21,7 @@ def test_mode_solver_semi_vectorial_te(overwrite):
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_mode_solver_semi_vectorial_tm(overwrite):
+def test_mode_solver_semi_vectorial_tm(overwrite: bool) -> None:
     mode_solver = mode_solver_semi(semi_vectorial_method="Ey", overwrite=overwrite)
     # modes = mode_solver.solve()
     # neff0 = modes["n_effs"][0].real
@@ -35,8 +33,12 @@ def test_mode_solver_semi_vectorial_tm(overwrite):
 
 @autoname
 def _semi(
-    n_modes=2, semi_vectorial_method="Ex", plot=False, plot_profile=False, **wg_kwargs
-):
+    n_modes: int = 2,
+    semi_vectorial_method: str = "Ex",
+    plot: bool = False,
+    plot_profile: bool = False,
+    **wg_kwargs
+) -> ModeSolverSemiVectorial:
     """
     returns mode solver with mode_solver.wg
     writes waveguide material index
@@ -45,6 +47,8 @@ def _semi(
     Args:
         n_modes: 2
         semi_vectorial_method: 'Ey' for TM, 'Ex' for TE
+        plot: plot modes
+        plot_profile: plot index profile
         wg_kwargs: for waveguide
     """
 
@@ -62,14 +66,14 @@ def _semi(
 
 
 def mode_solver_semi(
-    n_modes=2,
-    semi_vectorial_method="Ex",
-    overwrite=False,
-    plot=True,
-    plot_profile=False,
-    logscale=False,
+    n_modes: int = 2,
+    semi_vectorial_method: str = "Ex",
+    overwrite: bool = False,
+    plot: bool = False,
+    plot_profile: bool = False,
+    logscale: bool = False,
     **wg_kwargs
-):
+) -> ModeSolverSemiVectorial:
     """
     returns semi vectorial mode solver with the computed modes
 
@@ -77,14 +81,18 @@ def mode_solver_semi(
         n_modes: 2
         overwrite: whether to run again even if it finds the modes in CONFIG.cache
         semi_vectorial_method: 'Ey' for TM, 'Ex' for TE
+        overwrite: runs even
+        plot: plot modes
+        plot_profile: plot index profile
+        logscale: plots mode in logscale
         x_step: 0.02
         y_step: 0.02
-        wg_height: 0.22
-        wg_width: 0.5
-        slab_height: 0
-        sub_height: 0.5
+        thickness: 0.22
+        width: 0.5
+        slab_thickness: 0
+        sub_thickness: 0.5
         sub_width: 2.0
-        clad_height: 0.5
+        clad_thickness: 0.5
         n_sub: sio2
         n_wg: si
         n_clad: sio2
