@@ -1,22 +1,35 @@
+from typing import Dict, List, Tuple, Union
+
 import matplotlib.pylab as plt
 import numpy as np
 import pytest
 import tqdm
+from numpy import float64, ndarray
 
+from modes._structure import RidgeWaveguide
 from modes.mode_solver_full import mode_solver_full
 from modes.waveguide import waveguide
 
 
 def sweep_waveguide(
-    waveguides,
-    sweep_param_list,
-    plot=True,
-    x_label="waveguide width (um)",
-    fraction_mode_list=[],
-    overwrite=False,
-    n_modes=6,
-    legend=None,
-):
+    waveguides: List[RidgeWaveguide],
+    sweep_param_list: ndarray,
+    plot: bool = True,
+    x_label: str = "waveguide width (um)",
+    fraction_mode_list: List[int] = [],
+    overwrite: bool = False,
+    n_modes: int = 6,
+    legend: None = None,
+) -> Dict[
+    str,
+    Union[
+        List[ndarray],
+        List[List[Tuple[str, float64]]],
+        List[List[float64]],
+        List[List[List[Union[str, float]]]],
+        List[List[float]],
+    ],
+]:
     """
     Find the modes of many waveguides.
 
@@ -42,15 +55,15 @@ def sweep_waveguide(
         import numpy as np
         import modes as ms
 
-        wg_widths = np.arange(0.5, 2.0, 0.5)
-        wgs = [ms.waveguide(wg_width=wg_width) for wg_width in wg_widths]
+        widths = np.arange(0.5, 2.0, 0.5)
+        wgs = [ms.waveguide(width=width) for width in widths]
         r = ms.sweep_waveguide(
-            wgs, wg_widths, x_label="waveguide width", fraction_mode_list=[1, 2],
+            wgs, widths, x_label="waveguide width", fraction_mode_list=[1, 2],
         )
         print(r["n_effs"][0])
     """
     n_effs = []
-    mode_types = []
+    mode_types: List[Tuple[str, float64]] = []
     fractions_te = []
     fractions_tm = []
 
@@ -116,7 +129,11 @@ def sweep_waveguide(
         title = f"$n_{{eff}}$ {suffix}"
         y_label = "$n_{eff}$"
         ms._plot_n_effs(
-            filename_neffs, filename_fraction_te, x_label, y_label, title,
+            filename_neffs,
+            filename_fraction_te,
+            x_label,
+            y_label,
+            title,
         )
         if legend:
             plt.legend(legend)
@@ -124,7 +141,11 @@ def sweep_waveguide(
         plt.figure()
         title = f"TE Fraction {suffix}"
         ms._plot_fraction(
-            filename_fraction_te, x_label, "TE Fraction [%]", title, fraction_mode_list,
+            filename_fraction_te,
+            x_label,
+            "TE Fraction [%]",
+            title,
+            fraction_mode_list,
         )
         if legend:
             plt.legend(legend)
@@ -132,7 +153,11 @@ def sweep_waveguide(
         plt.figure()
         title = f"TM Fraction {suffix}"
         ms._plot_fraction(
-            filename_fraction_tm, x_label, "TM Fraction [%]", title, fraction_mode_list,
+            filename_fraction_tm,
+            x_label,
+            "TM Fraction [%]",
+            title,
+            fraction_mode_list,
         )
         if legend:
             plt.legend(legend)
@@ -141,11 +166,15 @@ def sweep_waveguide(
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_sweep(overwrite):
-    wg_widths = np.arange(0.5, 2.0, 0.5)
-    wgs = [waveguide(wg_width=wg_width) for wg_width in wg_widths]
+def test_sweep(overwrite: bool) -> None:
+    widths = np.arange(0.5, 2.0, 0.5)
+    wgs = [waveguide(width=width) for width in widths]
     r = sweep_waveguide(
-        wgs, wg_widths, n_modes=2, fraction_mode_list=[1, 2], overwrite=overwrite,
+        wgs,
+        widths,
+        n_modes=2,
+        fraction_mode_list=[1, 2],
+        overwrite=overwrite,
     )
     print(r["n_effs"][0])
     assert np.isclose(
@@ -155,11 +184,15 @@ def test_sweep(overwrite):
 
 
 @pytest.mark.parametrize("overwrite", [True, False])
-def test_sweep2(overwrite):
-    wg_widths = np.arange(0.3, 1.0, 0.5)
-    wgs = [waveguide(wg_width=wg_width) for wg_width in wg_widths]
+def test_sweep2(overwrite: bool) -> None:
+    widths = np.arange(0.3, 1.0, 0.5)
+    wgs = [waveguide(width=width) for width in widths]
     r = sweep_waveguide(
-        wgs, wg_widths, n_modes=2, fraction_mode_list=[1, 2], overwrite=overwrite,
+        wgs,
+        widths,
+        n_modes=2,
+        fraction_mode_list=[1, 2],
+        overwrite=overwrite,
     )
     print(r["n_effs"][0])
     assert np.isclose(
